// Copyright (c) 2009-2010 Volvox Development Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
//
// Author: Konstantin Lepa <konstantin.lepa@gmail.com>

#include "vxlog/logger.h"
#include <vector>
#include <vxlog/shared-ptr.h>
#include "vxlog/macros.h"
#include "utests/googletest.h"
#include "vxlog/outputter-interface.h"

using vxlog::OutputterInterface;
using vxlog::Level;

namespace {

class TestOutputter : public OutputterInterface {
 public:
  TestOutputter() {}

  void Print(Level::Type, const char *modname, const char *str) {
    test_string_ = std::string(modname) + " " + std::string(str);
  }
  void Flush() {}

  void Reset() { test_string_.clear(); }
  std::string test_string() { return test_string_; }

 private:
  std::string test_string_;

  VXLOG_DISALLOW_COPY_AND_ASSIGN(TestOutputter);
};

VXLOG_DEFINE_MODULE(TestModule, "Test Module");
typedef vxlog::Logger<TestModule> Log;

TEST(Log, SimpleLog) {
  vxlog::SharedPtr<TestOutputter>::Type outputter(new TestOutputter());
  Log::BindOutputter<TestOutputter>(vxlog::Level::kWarn, outputter);

  outputter->Reset();
  Log::Warn("%_ != %_ != %_", 1, 2.1, -5);
  EXPECT_STREQ("Test Module 1 != 2.1 != -5",
               outputter->test_string().c_str());

  outputter->Reset();
  Log::Warn("%_ %_ %_", 1);
  EXPECT_STREQ("Test Module 1 %_ %_",
               outputter->test_string().c_str());

  outputter->Reset();
  Log::Warn("%_", 1, 2);
  EXPECT_STREQ("Test Module 1",
               outputter->test_string().c_str());

  outputter->Reset();
  Log::Info("Invisible message");
  EXPECT_STREQ("",
               outputter->test_string().c_str());
}

}  // namespace

